gl.check.panel: Check a snp panel for a specified parameter

View source: R/gl.check.panel.r

gl.check.panelR Documentation

Check a snp panel for a specified parameter

Description

This function checks a panel how good it is to recreate the specified parameter of conservation concern (Ne, Fst, Ho etc.)

Usage

gl.check.panel(
  x,
  xorig,
  parameter = "Fst",
  neest.path = NULL,
  plot.out = TRUE,
  plot.file = NULL,
  plot.dir = NULL,
  verbose = NULL
)

Arguments

x

A 'dartR or genlight' object containing the SNP panel genomic data.

xorig

A 'dartR or genlight' object containing the original genomic data for comparison.

parameter

A character string specifying the parameter to check. Options include: Fst, He, Ho, Ne, Nall, Fis.

neest.path

Path to neestimator (see gl.LDNe)

plot.out

Logical. If 'TRUE', generates plots summarizing selected loci.

plot.file

A character string specifying the file name for saving plots. If 'NULL', plots are not saved.

plot.dir

A character string specifying the directory to save plots. Defaults to the working directory.

verbose

Integer level of verbosity for reporting progress and information.

Details

The function applies various methods to select loci based on the input 'dartR or genlight' object. Each method has specific criteria for selecting loci:

Value

A plot and the result of the linear regression

Examples

# Example usage:

# Select 20 loci randomly
selected <- gl.select.panel(possums.gl, method = "random", nl = 50)
gl.check.panel(selected, possums.gl, parameter="Fst")


dartR.popgen documentation built on March 16, 2026, 9:07 a.m.