- x
Name of the genlight object containing the SNP data [required].
- pop_name
Name of the population to analyse. If NULL all the
populations are analised [default NULL].
- chrom_name
Nme of the chromosome to analyse. If NULL all the
chromosomes are analised [default NULL].
- ld_max_pairwise
Maximum distance in number of base pairs at which LD
should be calculated [default 10000000].
- maf
Minor allele frequency (by population) threshold to filter out
loci. If a value > 1 is provided it will be interpreted as MAC (i.e. the
minimum number of times an allele needs to be observed) [default 0.05].
- ld_stat
The LD measure to be calculated: "LLR", "OR", "Q", "Covar",
"D.prime", "R.squared", and "R". See ld
(package snpStats) for details [default "R.squared"].
- ind.limit
Minimum number of individuals that a population should
contain to take it in account to report loci in LD [default 10].
- haplo_id
Whether to identify haplotypes [default FALSE].
- min_snps
Minimum number of SNPs that should have a haplotype to call
it [default 10].
- ld_threshold_haplo
Minimum LD between adjacent SNPs to call a
haplotype [default 0.5].
- target_snp
Position of target SNP [default NULL].
- coordinates
A vector of two elements with the start and end
coordinates in base pairs to which restrict the
analysis e.g. c(1,1000000) [default NULL].
- color_haplo
Color palette for haplotype plot. See details
[default "viridis"].
- color_het
Color for heterozygosity [default "deeppink"].
- plot.out
Specify if heatmap plot is to be produced [default TRUE].
- plot.save
Whethwr to save the plot in pdf format [default FALSE].
- plot.dir
Directory in which to save files [default = working directory]
- verbose
Verbosity: 0, silent or fatal errors; 1, begin and end; 2,
progress log; 3, progress and results summary; 5, full report
[default 2, unless specified using gl.set.verbosity].