View source: R/utils.get.allele.freq.r
| utils.get.allele.freq | R Documentation |
Generates percentage allele frequencies by locus and population – This is copy from package dartR function gl.percent.freq
utils.get.allele.freq(x, verbose = 2)
x |
Name of the genlight object containing the SNP or Tag P/A (SilicoDArT) data [required]. |
verbose |
Verbosity: 0, silent or fatal errors; 1, begin and end; 2, progress log; 3, progress and results summary; 5, full report [default 2 or as specified using gl.set.verbosity]. |
This is a support script, to take SNP data or SilicoDArT presence/absence data grouped into populations in a genlight object {adegenet} and generate a table of allele frequencies for each population and locus
A matrix with allele (SNP data) or presence/absence frequencies (Tag P/A data) broken down by population and locus
Custodian: Arthur Georges (Post to https://groups.google.com/d/forum/dartr)
m <- utils.get.allele.freq(testset.gl)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.