View source: R/gl.check.panel.r
| gl.check.panel | R Documentation |
This function checks a panel how good it is to recreate the specified parameter of conservation concern (Ne, Fst, Ho etc.)
gl.check.panel(
x,
xorig,
parameter = "Fst",
neest.path = NULL,
plot.out = TRUE,
plot.file = NULL,
plot.dir = NULL,
verbose = NULL
)
x |
A 'dartR or genlight' object containing the SNP panel genomic data. |
xorig |
A 'dartR or genlight' object containing the original genomic data for comparison. |
parameter |
A character string specifying the parameter to check. Options include: Fst, He, Ho, Ne, Nall, Fis. |
neest.path |
Path to neestimator (see gl.LDNe) |
plot.out |
Logical. If 'TRUE', generates plots summarizing selected loci. |
plot.file |
A character string specifying the file name for saving plots. If 'NULL', plots are not saved. |
plot.dir |
A character string specifying the directory to save plots. Defaults to the working directory. |
verbose |
Integer level of verbosity for reporting progress and information. |
The function applies various methods to select loci based on the input 'dartR or genlight' object. Each method has specific criteria for selecting loci:
A plot and the result of the linear regression
# Example usage:
# Select 20 loci randomly
selected <- gl.select.panel(possums.gl, method = "random", nl = 50)
gl.check.panel(selected, possums.gl, parameter="Fst")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.